@@ -56,21 +56,17 @@ class MyForm(QtGui.QMainWindow):
         QtCore.QObject.connect(self.ui.actionMenuAbout, QtCore.SIGNAL('triggered()'), self.showAbout)
         QtCore.QObject.connect(self.ui.actionMenuTips, QtCore.SIGNAL('triggered()'), self.showTips)
 
-        # get Current registered Cell ID
-        # can't get this to work in straight python, so cheat and run the command in bash
-        # Many thanks to the maemo.org wiki!
-        f=os.popen("dbus-send --system --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_registration_status")
-        dbusOP = f.readlines()
-        #print "dbusOP",dbusOP
-        #currCellIdAll = (dbusOP[3].split())
-        #print "currCellIdAll",currCellIdAll
-        currCellId = (dbusOP[3].split())[1]
-        print "Currently registered CellID is: ", int(currCellId)
-        #update UI with current CellID
-        self.ui.spinBoxCellID.setValue(int(currCellId))
-
         dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
         bus = dbus.SystemBus()
+        # get Current registered Cell ID
+        dbus_object = bus.get_object('com.nokia.phone.net', '/com/nokia/phone/net')
+        cellinfo = dbus.Interface(dbus_object, 'Phone.Net')
+#        cell_signal_handler(cellinfo.get_registration_status())
+        #cellinfo.get_registration_status()[2]
+        #cellinfo.get_selected_radio_access_technology()
+        #update UI with current CellID
+        self.ui.spinBoxCellID.setValue(cellinfo.get_registration_status()[2])
+
         bus.add_signal_receiver(cell_signal_handler, dbus_interface = "Phone.Net", signal_name = "registration_status_change")
         bus.add_signal_receiver(cell_signal_handler, dbus_interface = "Phone.Net", signal_name = "cell_info_change")
 
@@ -204,7 +200,7 @@ class MyForm(QtGui.QMainWindow):
 
 def add_two_button_alarm( message = "We are HERE!"):
     event = alarm.Event()
-    event.appid = 'myappid'
+    event.appid = 'restinpeace'
     event.message = message
 
     event.alarm_time = time() + 1
@@ -223,34 +219,34 @@ def add_two_button_alarm( message = "We are HERE!"):
     return cookie
 
 def cell_signal_handler(*args):
-    if( myapp.enableLogging ):
-        myapp.fileObj.write( time() + '--> ' + str(args[4]) + ', ' + str(args[3]) + ', ' + str(args[2]) + '\n' )
+    if( app_object.enableLogging ):
+        app_object.fileObj.write( time() + '--> ' + str(args[4]) + ', ' + str(args[3]) + ', ' + str(args[2]) + '\n' )
 
     # Update UI with current CellID
-    myapp.ui.spinBoxCellID.setSuffix("")
-    myapp.ui.spinBoxCellID.setValue(args[2])
-    for key in myapp.cellID_list.iterkeys():
-        if myapp.cellID_list[key].__contains__(args[2]):
-            myapp.cellID_name = key
+    app_object.ui.spinBoxCellID.setSuffix("")
+    app_object.ui.spinBoxCellID.setValue(args[2])
+    for key in app_object.cellID_list.iterkeys():
+        if app_object.cellID_list[key].__contains__(args[2]):
+            app_object.cellID_name = key
             break
-    myapp.ui.spinBoxCellID.setSuffix(": "+myapp.cellID_name)
+    app_object.ui.spinBoxCellID.setSuffix(": "+app_object.cellID_name)
 
     # Does it match the preset CellID?
-    if( myapp.searchCellID ):
-        if( args[2] in myapp.searchCellID ):
-            if( myapp.enableAlarm ):
-                myapp.enableAlarm = False
-                myapp.ui.checkBoxAlarm.setTristate(False)
+    if( app_object.searchCellID ):
+        if( args[2] in app_object.searchCellID ):
+            if( app_object.enableAlarm ):
+                app_object.enableAlarm = False
+                app_object.ui.checkBoxAlarm.setTristate(False)
                 add_two_button_alarm()
-                #sys.exit(myapp.exec_())
-                #myapp.ui.centralwidget.setEnabled(True)
+                #sys.exit(app_object.exec_())
+                #app_object.ui.centralwidget.setEnabled(True)
 
             # Even if there is no alarm, give some feedback to UI that we're arrived!
-            myapp.ui.pushButtonStart.setText("We are HERE!")
+            app_object.ui.pushButtonStart.setText("We are HERE!")
 
-    if( myapp.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
-        myapp.enableGSMAlarm = False
-        myapp.ui.checkBoxGSMAlarm.setChecked(False)
+    if( app_object.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
+        app_object.enableGSMAlarm = False
+        app_object.ui.checkBoxGSMAlarm.setChecked(False)
         add_two_button_alarm("GSM network available. You may not see it in the status panel if that's not your operator's station.")
 
 if __name__ == '__main__':
@@ -258,6 +254,6 @@ if __name__ == '__main__':
 
     #workaround for bug #6642
     import gobject
-    myapp = MyForm()
-    myapp.show()
+    app_object = MyForm()
+    app_object.show()
     sys.exit(app.exec_())
